/**
 * Provide some common functions for interacting with forms
 */
jQuery(document).ready(function($) {
    /**
     * Field definition
     * - name: field name
     * - id: field id
     * - description: the description of the field, to display
     * - type: what type of field
     * - options: for a select or multicheckbox, the options to display
     * - url: url to fetch options for a select or multicheckbox, alternative to options
     */
    /**
     * Make a table row for a field
     */
    rowForField = function (field)
    {
        switch (field.type) {
            case 'checkbox':
                return checkboxForField(field);
                break;
            case 'text':
                return textForField(field);
                break;
            case 'textarea':
                return textareaForField(field);
                break;
            case 'password':
                return passwordForField(field);
                break;
            case 'select':
                return selectForField(field);
                break;
            case 'multicheckbox':
                return multicheckboxForField(field);
                break;
            default:
                
        }
    }

    function checkboxForField(field)
    {
        var checked = ('value' in field) ? (('' != field.value) ? 'checked' : '') : '';
        return '<tr><th><label for="'+field.id+'">'+field.name+'</label></th><td><input id="'+field.id+'" name="'+field.id+'" type="checkbox" value="1" '+checked+'/></td><td>'+field.description+' </td></tr>';
    }

    function textForField(field)
    {
        var value = ('value' in field) ? field.value : '';
        return '<tr><th><label for="'+field.id+'">'+field.name+'</label></th><td><input id="'+field.id+'" name="'+field.id+'" type="text" value="'+value+'"/></td><td>'+field.description+' </td></tr>';
    }

    function textareaForField(field)
    {
        var value = ('value' in field) ? field.value : '';
        return '<tr><th><label for="'+field.id+'">'+field.name+'</label></th><td><textarea id="'+field.id+'" name="'+field.id+'">'+value+'</textarea></td><td>'+field.description+' </td></tr>';
    }

    function passwordForField(field)
    {
        var value = ('value' in field) ? field.value : '';
        return '<tr><th><label for="'+field.id+'">'+field.name+'</label></th><td><input id="'+field.id+'" name="'+field.id+'" type="password" value="'+value+'"/></td><td>'+field.description+' </td></tr>';
    }

    function selectForField(field)
    {
        console.log('loading select for field:' + field.name);
        var value = ('value' in field) ? field.value : '';
        var options = '<option value=""></option>';
        if ('options' in field) {
            field.options.forEach((option) => options += `<option value="${option.value}">${option.label}</option>`);
        }
        if ('route' in field) {
            packets += 1;
            $.ajax({
                method: 'GET',
                url: field.route,
                beforeSend: function ( xhr ) {
                    xhr.setRequestHeader('X-WP-Nonce', DMPROprofile.api.nonce);
                },
            }).done( function (r) {
                for (var key of Object.keys(r)) {
                    if ('object' == typeof(r[key])) {
                        $('select#'+field.id).append(`<option value="${r[key].id}">${r[key].name}</option>`);
                    } else {
                        $('select#'+field.id).append(`<option value="${key}">${r[key]}</option>`);
                    }
                }
                packets -= 1;
            }).fail( function (r) {
                var message = DMPROprofile.strings.error;
                if( r.hasOwnProperty( 'message' ) ){
                    message = r.message;
                }
                $( '#feedback' ).html( '<p>' + message + '</p>' );
                packets -= 1;
            });
        }


        return '<tr><th><label for="'+field.id+'">'+field.name+'</label></th><td><select id="'+field.id+'" name="'+field.id+'">'+options+'</select></td><td>'+field.description+' </td></tr>';
    }

    function multicheckboxForField(field)
    {
        var value = ('value' in field) ? field.value : '';
        var options = '';
        if ('options' in field) {
            field.options.forEach((option) => options += `<input type="checkbox" name="${field.name}[]" value="${option.value}">${option.label}</input><br />`);
        }
        if ('route' in field) {
                packets += 1;
            $.ajax({
                method: 'GET',
                url: field.route,
                beforeSend: function ( xhr ) {
                    xhr.setRequestHeader('X-WP-Nonce', DMPROprofile.api.nonce);
                },
            }).done( function (r) {
                for (var key of Object.keys(r)) {
                    $('div#'+field.id).append(`<input type="checkbox" name="${field.name.toLowerCase()}[]" value="${key}" >${r[key]}</input><br />`);
                }
                packets -= 1;
            }).fail( function (r) {
                var message = DMPROprofile.strings.error;
                if( r.hasOwnProperty( 'message' ) ){
                    message = r.message;
                }
                $( '#feedback' ).html( '<p>' + message + '</p>' );
                packets -= 1;
            });
        }

        return '<tr><th><label for="'+field.id+'">'+field.name+'</label></th><td><div id="'+field.id+'" name="'+field.id+'">'+options+'</div></td><td>'+field.description+' </td></tr>';
    }
});
