jQuery(document).ready(function($) {
    $('#integration').on('change', function() {
        //document.forms['integrationForm'].submit();
        // load form
        loadIntegrationSettingsForm(this.value);
    });

    // submit form values
    $( '#integrationForm' ).on( 'submit', function (e) {
        e.preventDefault();
        updateIntegrationSettings(e);
    });

    /**
     * load the setting information from the server
     * build the form
     * populate form with values, defaults or settings
     */
    function loadIntegrationSettingsForm(integration)
    {
        // clear the form it already has fields
        $('table#integration-settings').empty();

        // load the form fields
        $.ajax({
            method: 'GET',
            url: DMPROintegration.api.url + '&integration=' + integration,
            beforeSend: function ( xhr ) {
                xhr.setRequestHeader( 'X-WP-Nonce', DMPROintegration.api.nonce );
            }
        }).then( function ( data ) {
            // add inputs to the form
            Object.keys(data).forEach((key) => $('table#integration-settings').append(rowForField(data[key])));
        });

        function rowForField(field)
        {
            switch (field.type) {
                case 'checkbox':
                    return checkboxForField(field);
                    break;
                case 'text':
                    return textForField(field);
                    break;
                case 'password':
                    return passwordForField(field);
                    break;
                default:
                    
            }
        }

        function checkboxForField(field)
        {
            var checked = ('value' in field) ? (('' != field.value) ? 'checked' : '') : '';
            return '<tr><td><label for="'+field.id+'">'+field.name+'</label></td><td><input id="'+field.id+'" name="'+field.id+'" type="checkbox" value="1" '+checked+'/></td><td>'+field.description+' </td></tr>';
        }

        function textForField(field)
        {
            var value = ('value' in field) ? field.value : '';
            return '<tr><td><label for="'+field.id+'">'+field.name+'</label></td><td><input id="'+field.id+'" name="'+field.id+'" type="text" value="'+value+'"/></td><td>'+field.description+' </td></tr>';
        }

        function passwordForField(field)
        {
            var value = ('value' in field) ? field.value : '';
            return '<tr><td><label for="'+field.id+'">'+field.name+'</label></td><td><input id="'+field.id+'" name="'+field.id+'" type="password" value="'+value+'"/></td><td>'+field.description+' </td></tr>';
        }
    }

    function updateIntegrationSettings(e)
    {
        var data = $('form#integrationForm').serializeArray().reduce(function (json, { name, value }) {
              json[name] = value;
              return json;
            }, {}
        );

        $.ajax({
            method: 'POST',
            url: DMPROintegration.api.url,
            beforeSend: function ( xhr ) {
                xhr.setRequestHeader('X-WP-Nonce', DMPROintegration.api.nonce);
            },
            data:data
        }).done( function (r) {
            console.log('done');
            console.log(r);
            $( '#feedback' ).html( '<p>' + DMPROintegration.strings.saved + '</p>' );
        }).fail( function (r) {
            console.log('fail');
            console.log(r);
            var message = DMPROintegration.strings.error;
            if( r.hasOwnProperty( 'message' ) ){
                message = r.message;
            }
            $( '#feedback' ).html( '<p>' + message + '</p>' );
        })
    }
});
