<?php declare(strict_types=1);
namespace DiviManagerPro\Action;

defined( 'ABSPATH' ) or die( 'Unexpected access' );

use DiviManager\Action\AbstractAction;
use DiviManager\Service\Site as SiteService;

/**
 * Perform actions with the platform
 *
 * refresh the platform information for a site
 * clone a site on that platform
 *
 * FIXME: refactor into a separate service
 */
class Migrate extends AbstractAction
{
    const ACTION_EXPORT = 'migrate_export';
    const ACTION_FETCH  = 'migrate_fetch';

    /**
     * @var SiteService
     */
    protected $siteService;

    public function __construct()
    {
    }

    public function setSiteService(SiteService $s)
    {
        $this->siteService = $s;
    }

    /**
     * Check that the fetch request includes a nonce assigned to that site
     *
     * @return null|WP_Error null if valid, WP_Error if invalid
     */
    public function verifyNonce($request = null)
    {
        var_dump($_REQUEST, $_POST, $_GET);
        var_dump(\get_headers());
        die(__FILE__);
        return new \WP_Error(
            'rest_cannot_migrate',
            __( 'testing.' ),
            [ 'status' => rest_authorization_required_code() ]
        );
        $srcSiteID = $_REQUEST['source'];

        $site = $this->siteService->getSite($srcSiteID);
        if (null === $site) {
            \WP_CLI::error( 'Source site not found' );
        }
        $exportData = $site->getData()['exportData'];
        $nonce = $exportData['status']['nonce'];
        // needs better security
        //if (! (check_ajax_referer( 'dmp-migrate-import' )) ) {
        if ($_REQUEST['_ajax_nonce'] != $nonce) {
            return new \WP_Error(
                'rest_cannot_migrate',
                __( 'Sorry, you are not allowed to export/import data for this site.' ),
                [ 'status' => rest_authorization_required_code() ]
            );
        }

        return true;
    }
  
    public function registerRoutes($api)
    {
        register_rest_route( $api->getBase(), '/migrate/import/fetch', [
            'methods' => \WP_REST_Server::EDITABLE,
            'callback' => [$this, 'getImportFileForSite'],
            'permission_callback' => [$this, 'verifyNonce'],
        ]);
    }

    public function registerActions($worker)
    {
        $worker->actions[self::ACTION_EXPORT] = [$this, 'exportFromSite'];
        $worker->actions[self::ACTION_FETCH] = [$this, 'fetchFromSite'];
    }

    /**
     * Action endpoints
     */
    /**
     * Tell a site to export its data for later retrieval
     * Returns the export information
     */
    public function exportFromSite($site)
    {
        $endpoint = '?rest_route=/dm/v3/migrate/export';

        $response = $this->requestEndpointFromSite($endpoint, $site);

		if( is_wp_error( $response ) ) {
			echo 'There was a problem communicating with the site.'.$site->getUrl() . $endpoint;
            echo $response->get_error_message();
            var_dump($response);
            wp_die();
        }

        var_dump($response);
        die(__FILE__);
        $data = $response->decode_body(true);

        $data['status'] = [
            'wpcontent' => false,
            'database' => false,
            'status' => 'export',
            'nonce' =>  \wp_create_nonce( 'dmp-migrate-import' ),
        ];

        // save the export data to the site
        $siteData = $site->getData();
        $siteData['exportData'] = $data;
        $site->setData($siteData);
        $this->siteService->updateSite($site);

        return $data;
    }

    /**
     * Fetch one of the export files from a site
     */
    public function fetchFromSite($site, $file)
    {
        $endpoint = '?rest_route=/dm/v3/migrate/fetch';
        $response = $this->postEndpointToSite($endpoint, $site, ['file' => $file]);

		if( is_wp_error( $response ) ) {
			echo 'There was a problem communicating with the site.'.$site->getUrl() . $endpoint;
            echo $response->get_error_message();
            wp_die('error');
        }

        if ('wpcontent' == $file) {
            $extension = 'tbz2';
        } elseif ('database' == $file) {
            $extension = 'sql';
        }

        $tmpFile = tempnam(sys_get_temp_dir(), 'file');
        rename($tmpFile, $tmpFile . '.' . $extension);
        $tmpFile = $tmpFile . '.' . $extension;
        $bytes = file_put_contents($tmpFile, $response->body);

        // update export data for the site
        $siteData = $site->getData();
        $siteData['exportData']['status'][$file] = $tmpFile;
        var_dump($siteData['exportData']);
        if (false != $siteData['exportData']['status']['wpcontent'] &&
            false != $siteData['exportData']['status']['database']) {
            $siteData['exportData']['status']['status'] = 'Downloaded';
        }
        $site->setData($siteData);
        $this->siteService->updateSite($site);

        return [$tmpFile, $bytes];
    }

    /**
     * Setup import on a remote site
     */
    public function importToSite($site, $fromSite)
    {
        $endpoint = '?rest_route=/dm/v3/migrate/import/start';
        $managerRestUrl = \get_rest_url();

        $data = $fromSite->getData();
        $exportData = $fromSite->getData()['exportData'];
        //$nonce = \wp_create_nonce( 'dmp-migrate-import'.$site->getId() );
        // use this to check the nonce:
        //check_ajax_referer( 'dmp-migrate-import'.$site->getId() );
        //or
        //wp_verify_nonce( $_REQUEST['my_nonce'], 'dmp-migrate-import'.$site->getId() );
        $data = [
            'source' => $fromSite->getId(),
            'prefix' => $exportData['prefix'],
            'manager' => $managerRestUrl . 'dm/v3/migrate/import/fetch',
            'nonce' => $exportData['status']['nonce'],
            'files' => [
                'wpcontent',
                'database',
            ]
        ];

        if ($this->isDryrun()) {
            //var_dump(__FUNCTION__, $endpoint, $data, $site->getId());
        //} else {
            $response = $this->postEndpointToSite($endpoint, $site, $data);

            if( is_wp_error( $response ) ) {
                echo 'There was a problem communicating with the site.'.$site->getUrl() . $endpoint;
                echo $response->get_error_message();
                wp_die('error');
            }
        }

        $data = $response->decode_body(true);
        $siteData = $site->getData();
        $siteData['importData'] = $data;
        $site->setData($siteData);
        $this->siteService->updateSite($site);

        return $data;

/*
        if (file_exists($file)) {
            $endpoint = '?rest_route=/dm/v3/migrate/import';
			$data = [
                'importFile' => $cFile,
                //'importFile[1]' => $cFile,
                //'importFile[2]' => $cFile,
			];
            $response = $this->postEndpointToSite($endpoint, $site, $data);

            if( is_wp_error( $response ) ) {
                echo 'There was a problem communicating with the site.'.$site->getUrl() . $endpoint;
                echo $response->get_error_message();
                wp_die('error');
            }

            var_dump($response);
            die(__FILE__.__LINE__);

            $file = tempnam(sys_get_temp_dir(), 'file');
            $bytes = file_put_contents($file, $response->body);

            return [$file, $bytes];
        } else {
            throw new \Exception('File does not exist: ' . $file);
        }
 */
    }

    /**
     * Get the status of the import operation from the site
     */
    public function importStatusFromSite($site)
    {
        $endpoint = '?rest_route=/dm/v3/migrate/import/status';
        $response = $this->requestEndpointFromSite($endpoint, $site);

        if( is_wp_error( $response ) ) {
            echo 'There was a problem communicating with the site.'.$site->getUrl() . $endpoint;
            echo $response->get_error_message();
            wp_die('error');
        }

        $data = $response->decode_body(true);
        $siteData = $site->getData();
        $siteData['importData'] = $data;
        $site->setData($siteData);
        $this->siteService->updateSite($site);

        return $data;
    }

    /**
     * Tell the remote site to clear the import files, freeing up the space again
     */
    public function purgeImportFilesOnSite($site)
    {
        die(__FUNCTION__.__FILE__);
    }

    /**
     * Send the specified export file to the site for import
    public function importPushToSite($dstSite, $srcSite, $file)
    {
        throw new \Exception('DO NOT USE');
        $exportData = $srcSite->getData()['exportData'];
        $filepath = $exportData['status'][$file];
        if (! file_exists($filepath)) {
            throw new \Exception('File not found for source site:' . $filepath);
        }

        $response = $this->curlPostFileToSite($dstSite, $filepath);
        return $response;
    }
     */

    /**
     * API Route endpoints
     */
    /**
     * Send the specified export file to the site for import
     */
    public function getImportFileForSite($request)
    {
        $params = $request->get_params();

        $file = $params['file'];
        $srcSiteID = $params['source'];

        $site = $this->siteService->getSite($srcSiteID);
        if (null === $site) {
            \WP_CLI::error( 'Source site not found' );
        }

        $siteData = $site->getData();
        $exportData = $siteData['exportData'];

        if (isset($exportData['status'][$file])) {
            $dlFile = $exportData['status'][$file];
            if (file_exists($dlFile)) {
                $siteData['exportData']['status']['nonce'] = 'INVALID';
                $site->setData($siteData);
                $this->siteService->updateSite($site);
                $fd = \fopen($dlFile, 'r');
                $info = pathinfo($dlFile);
                // do not cache this file
                header('Cache-Control: no-cache, must-revalidate');
                header('Pragma: no-cache');
                // attachment, keep the name of the file
                header('Content-Disposition: attachment; filename=' . basename($dlFile) . '.' . $info['extension']);
                header('Content-Type: application/octet-stream');
                // size of file
                header('Content-Length: ' . filesize($dlFile));
                fpassthru($fd);
                fclose($fd);
                return;
            }
        }


        return new \WP_Error('File not found for download: ' . $file);
    }
}
