<?php declare(strict_types=1);
namespace DiviManagerPro;

defined( 'ABSPATH' ) or die( 'Unexpected access' );

use DiviManager\Registry;

/**
 * Support configuration and admin of advanced divimanager features
 */
class Admin
{
    protected $hookPrefix = 'divimanager'; // need our own prefix?  dmpro?
 
    /**
     * @var Registry the core class
     */
    protected $registry;

    /**
     * @var String plugin slug, used as base for options
     */
    protected $slug;

    /**
     * @var Option options manager
     */
    protected $option;

    /**
     * @var boolean is debug enabled?
     */
    protected $debug;

    public function __construct()
    {
        $this->slug = 'divimanager-pro';
    }

    public function setOption($option)
    {   
        $this->option = $option;
    }

    public function setRegistry(Registry $registry)
    {   
        $this->registry = $registry;
    }

    public function setSlug(String $s)
    {
        $this->slug = $s;
    }

    public function setDebug(bool $debug)
    {
        $this->debug = true;
    }

    public function isDebug()
    {
        return true === $this->debug;
    }

    public function init()
    {
        //add_action( 'admin_menu', [$this, 'admin_menu'] );
        add_action( $this->hookPrefix . '_admin_menu', [$this, 'admin_menu'], 11);
        add_filter( 'divimanager_mysettings', [$this, 'register_mysettings'], 2 );
        add_filter( 'divimanager_options_validate', [$this, 'plugin_options_validate'] );
        add_action( 'admin_enqueue_scripts', [$this, 'enqueue_scripts'] );
    }

    /**
     * Enqueue javascript for pages
     *
     * https://developer.wordpress.org/plugins/javascript/enqueuing/
     */
    public function enqueue_scripts($hook)
    {
        if( ! \wp_script_is( 'form.js', 'registered' ) ){
            $this->register_scripts($hook);
        }

        //\wp_enqueue_script( 'form.js' );
    }

    /**
     * Register our scripts so wordpress knows about them
     */
    public function register_scripts($hook)
    {
        // register our base form script
        \wp_register_script(
            'form.js',
            \plugins_url( '/js/form.js', $this->registry->getService(DiviManagerPro::class)->getMainPluginFile() ),
            [ 'jquery' ],
            '1.0.0',
            [
               'in_footer' => false,
            ]
        );
    }

    public function register_mysettings($settings)
    {
        $optionName = $this->option->getOptionName();
        $sectionName = $this->slug . '_section_pro';
        $settings[$this->slug . '-pro'] = [
            $sectionName,
            'Pro Settings',
            [$this, 'pro_settings'],
            $optionName,
            'settings' => [
                [
                    $this->slug . '_field_license',
                    'License Key',
                    [$this, 'setting_license'],
                    $optionName,
                    $sectionName,
                    [
                        'label_for' => 'divimanager_options[license]'
                    ]
                ],
                [
                    $this->slug . '_field_email',
                    'License Email',
                    [$this, 'setting_email'],
                    $optionName,
                    $sectionName,
                    [
                        'label_for' => 'divimanager_options[email]'
                    ]
                ],
            ]
        ];

        return $settings;
    }

    public function admin_menu ()
    {
        // add the integration page
        $integrationPage = $this->registry->getService(Page\Integration::class);
        $integrationHook = add_submenu_page( 'divimanager-menu', 'Integrations', 'Integrations', 'manage_options', 'divimanager-integration', [$integrationPage, 'index']);

        // add the server pages
        $serverPage  = $this->registry->getService(Page\Server::class);
        $serverHook = add_submenu_page( 'divimanager-menu', 'Servers', 'Servers', 'manage_options', 'divimanager-server', [$serverPage, 'index']);

        // add the provision pages
        $provisionPage  = $this->registry->getService(Page\Provision::class);
        $provisionHook = add_submenu_page( 'divimanager-menu', 'server', 'Provisions', 'manage_options', 'divimanager-provision', [$provisionPage, 'index']);
    }

    /**
     * custom plugin settings
     */
    public function pro_settings($args)
    {
        echo '<p id="' . esc_attr( $args['id'] ) . '">All the settings which the DiviManager-Pro version will use.</p>';
    }

    public function setting_license($args)
    {
        $license = $this->option->getOption('license');
        echo '<input id="' . esc_attr( $args['label_for'] ) . '" name="' . esc_attr( $args['label_for'] ) . '" type="password" value="' . esc_attr ( $license ) . '" />';
    }

    public function setting_email($args)
    {
        $email = $this->option->getOption('email');
        echo '<input id="' . esc_attr( $args['label_for'] ) . '" name="' . esc_attr( $args['label_for'] ) . '" type="text" value="' . esc_attr ( $email ) . '" />';
    }

    public function plugin_options_validate($input)
    {
        $input['license'] = \sanitize_text_field($input['license']);
        $email = \sanitize_text_field($input['email']);
        if (is_email($email)) {
            $input['email'] = $email;
        } else {
            $input['email'] = '';
        }

        return $input;
    }
}
