<?php declare(strict_types=1);
namespace DiviManagerPro;

defined( 'ABSPATH' ) or die( 'Unexpected access' );

/**
 * api support
 *
 * @see https://developer.wordpress.org/rest-api/extending-the-rest-api/adding-custom-endpoints/
 */
use DiviManagerPro\DiviManagerPro;
use DiviManager\Registry;
use DiviManager\Service\Site as SiteService;

class Api extends \WP_REST_Controller
{
    /**
     * @var DiviManagerPro
     * Instance of the main class
     */
    protected $manager;

    /**
     * @var String
     */
    protected $base;

    public function setManager(DiviManagerPro $m)
    {
        $this->manager = $m;
    }

    public function setRegistry(Registry $r)
    {
        $this->registry = $r;
    }

    public function setBase($base)
    {
        $this->base = $base;
    }

    public function getBase()
    {
        return $this->base;
    }

    public function register_rest_routes()
    {
        // server site api for the migration action
        // FIXME:  inject the action instance
        $migrate = new Action\Migrate();
        $migrate->setSiteService($this->registry->getService(SiteService::class));
        $migrate->registerRoutes($this);
    }

    /**
     * Check that the request has a valid token
     *
     * @return null|WP_Error null if valid, WP_Error if invalid
     */
    public function verifyToken($request = null)
    {
        // from wp-includes/rest-api/endpoints/class-wp-rest-plugins-controller.php
        //if ( ! current_user_can( 'activate_plugins' ) ) {
        //if ( ! current_user_can( 'manage_options' ) ) {
        if ( ! current_user_can( 'administrator' ) ) {
            return new \WP_Error(
                'rest_cannot_view_plugins',
                __( 'Sorry, you are not allowed to manage plugins for this site.' ),
                array( 'status' => rest_authorization_required_code() )
            );
        }

        return true;
    }
}
