<?php declare(strict_types=1);
namespace DiviManagerPro\Integration;

defined( 'ABSPATH' ) or die( 'Unexpected access' );

/**
 * Base class for service integrations which Manager supports.
 * Specifics should be provided by individual classes
 */
abstract class AbstractIntegration implements IntegrationInterface
{
    public const SERVICE_DNS  = 'dns';
    public const SERVICE_HOST = 'host';
    public const OPTION_KEY = 'integrations';

    /**
     * @var String our id for the manager
     */
    protected $id;

    /**
     * @var String What type of service is this integration?
     */
    protected $type;

    /**
     * @var String A name for this profile
     */
    protected $name;

    /**
     * @var array
     *
     * The options for this integration
     */
    protected $options;

    public function getId()
    {
        return $this->id;
    }
    public function setId($newId)
    {
        $this->id = $newId;
        return $this;
    }

    public function getType()
    {
        return $this->type;
    }
    public function setType($newType)
    {
        $this->type = $newType;
        return $this;
    }

    public function getName()
    {
        return $this->name;
    }
    public function setName($newName)
    {
        $this->name = $newName;
        return $this;
    }

    /**
     * Get all the host options if this is a hosting service
     *
     * @return array
     */
    public function getHostOptions()
    {
        return [];
    }

    /**
     * Whether this service is enabled
     *
     * @return bool
     */
    public function isEnabled()
    {
        $this->option = $this->registry->getService(Option::class);
        return true == $this->option->getOption(self::OPTION_ENABLED);
    }

    public function getOptions()
    {
        if (empty($this->options)) {
            $options = $this->option->getOption(self::OPTION_KEY);
            if (isset($options[$this->getId()])) {
                $this->options = $options[$this->getId()];
            }
        }
        return $this->options;
    }

    public function setOptions(array $newOptions = null)
    {
        die(__FILE__.__FUNCTION__);
        if (null === $newOptions) {
            $newOptions = [];
        }
        $this->options = $newOptions;
        return $this;
    }
}
