<?php declare(strict_types=1);
namespace DiviManagerPro\Integration\Dnsmadeeasy;

defined( 'ABSPATH' ) or die( 'Unexpected access' );

use DiviManager\Registry;

/**
 * Support configuration and admin features for the Dnsmadeeasy platform
 */
class Admin
{
    /**
     * @var Registry the core class
     */
    protected $registry;

    /**
     * @var String plugin slug, used as base for options
     */
    protected $slug;

    /**
     * @var Option options manager
     */
    protected $option;

    /**
     * @var Dnsmadeeasy the dnsmadeeasy extension main class
     */
    protected $dnsmadeeasy;

    public function __construct()
    {
        $this->slug = 'divimanager-pro';
    }

    public function setOption($option)
    {   
        $this->option = $option;
    }

    public function setDnsmadeeasy(Dnsmadeeasy $d)
    {
        $this->dnsmadeeasy = $d;
    }

    public function setRegistry(Registry $registry)
    {   
        $this->registry = $registry;
    }

    public function setSlug(String $s)
    {
        $this->slug = $s;
    }

	public function init()
    {   
        add_filter( 'divimanager_mysettings', [$this, 'register_mysettings'], 4 );
        add_filter( 'divimanager_options_validate', [$this, 'plugin_options_validate'] );
    }
    
    public function register_mysettings($settings)
    {
        $sectionName = $this->slug . '_section_dnsmadeeasy';
        $optionName = $this->option->getOptionName();
        $settings[$this->slug . '-dnsmadeeasy'] = [
			$sectionName,
			'Dnsmadeeasy Settings',
			[$this, 'dnsmadeeasy_settings'],
			$optionName,
            'settings' => [
            ]
        ];
        $settings[$this->slug . '-dnsmadeeasy']['settings'][] = [   
            $this->slug . '_field_platforms_dnsmadeeasy_enabled',
            'DNS Made Easy Enabled',
            [$this, 'plugin_setting_dnsmadeeasy_enabled'],
            $optionName,
            $sectionName,
            [   
                'label_for' => 'divimanager_options[dnsmadeeasy_enabled]'
            ]
        ];
        if ($this->dnsmadeeasy->isEnabled()) {
            //['name' => 'DME API Url', 'type' => 'text', 'field' => 'dmeApiUrl', 'description' => 'Dnsmadeeasy API URL, should be set to https://api.dnsmadeeasy.com/'],
            $settings[$this->slug . '-dnsmadeeasy']['settings'][] = [
                $this->slug . '_field_platforms_dnsmadeeasy_dmeapiurl',
                'DME API Url',
                [$this, 'plugin_setting_dmeapiurl'],
                $optionName,
                $sectionName,
                [   
                    'label_for' => 'divimanager_options[platforms][dnsmadeeasy][dmeapiurl]'
                ],
                'Dnsmadeeasy API URL, should be set to https://api.dnsmadeeasy.com/',
            ];
            //['name' => 'DME API Key', 'type' => 'password', 'field' => 'dmeApiKey', 'description' => 'API key for dnsmadeeasy service'],
            $settings[$this->slug . '-dnsmadeeasy']['settings'][] = [
                $this->slug . '_field_platforms_dnsmadeeasy_dmeapikey',
                'DME API Key',
                [$this, 'plugin_setting_dmeapikey'],
                $optionName,
                $sectionName,
                [   
                    'label_for' => 'divimanager_options[platforms][dnsmadeeasy][dmeapikey]'
                ],
                'API key for dnsmadeeasy service',
            ];
            //['name' => 'DME Secret Key', 'type' => 'password', 'field' => 'dmeSecretKey', 'description' => 'Secret key for dnsmadeeasy service'],
            $settings[$this->slug . '-dnsmadeeasy']['settings'][] = [
                $this->slug . '_field_platforms_dnsmadeeasy_dmesecretkey',
                'DME Secret Key',
                [$this, 'plugin_setting_dmesecretkey'],
                $optionName,
                $sectionName,
                [   
                    'label_for' => 'divimanager_options[platforms][dnsmadeeasy][dmesecretkey]'
                ],
                'Secret key for dnsmadeeasy service',
            ];
            //['name' => 'DME Domain ID', 'type' => 'text', 'field' => 'dmeDomainID', 'description' => 'Domain ID on dnemadeeasy to which the staging domains will be added'],
            $settings[$this->slug . '-dnsmadeeasy']['settings'][] = [
                $this->slug . '_field_platforms_dnsmadeeasy_dmedomainid',
                'DME Domain ID',
                [$this, 'plugin_setting_dmedomainid'],
                $optionName,
                $sectionName,
                [   
                    'label_for' => 'divimanager_options[platforms][dnsmadeeasy][dmedomainid]'
                ],
                'Domain ID on dnemadeeasy to which the staging domains will be added',
            ];
            //['name' => 'DME Server IP', 'type' => 'text', 'field' => 'dmeServerIP', 'description' => 'IP of the server on which the sites are being installed'],
            $settings[$this->slug . '-dnsmadeeasy']['settings'][] = [
                $this->slug . '_field_platforms_dnsmadeeasy_dmeserverip',
                'DME Server IP',
                [$this, 'plugin_setting_dmeserverip'],
                $optionName,
                $sectionName,
                [   
                    'label_for' => 'divimanager_options[platforms][dnsmadeeasy][dmeserverip]'
                ],
                'IP of the server on which the sites are being installed',
            ];
            //['name' => 'Staging Domain', 'type' => 'text', 'field' => 'stagingDomain', 'description' => 'The domain the websites will be added to as subdomains'],
            $settings[$this->slug . '-dnsmadeeasy']['settings'][] = [
                $this->slug . '_field_platforms_dnsmadeeasy_dmestaging',
                'Staging Domain',
                [$this, 'plugin_setting_dmestaging'],
                $optionName,
                $sectionName,
                [   
                    'label_for' => 'divimanager_options[platforms][dnsmadeeasy][dmestaging]'
                ],
                'The domain the websites will be added to as subdomains',
            ];
        }

		return $settings;
    }

    /**
     * custom plugin settings
     */
    public function dnsmadeeasy_settings($args)
    {   
        echo '<p id="' . esc_attr( $args['id'] ) . '">All the settings which the report aggregator extension will use.  Leave blank to use default values.</p>';
    }

    public function plugin_setting_dnsmadeeasy_enabled($args)
    {
        $enabled = $this->option->getOption('dnsmadeeasy_enabled');
        if (true == $enabled) {
            $checked = 'checked';
        } else {
            $checked = '';
        }
        echo '<input id="' . esc_attr( $args['label_for'] ) . '" name="' . esc_attr( $args['label_for'] ) . '" type="checkbox" size="40" value="true" '.$checked.'/>';
    }

    public function plugin_setting_dmeapiurl($args)
    {
        $dmeapiurl = $this->option->getOption('platforms')['dnsmadeeasy']['dmeapiurl'];
        echo '<input id="' . esc_attr( $args['label_for'] ) . '" name="' . esc_attr( $args['label_for'] ) . '" type="text" value="' . esc_attr ( $dmeapiurl ) . '" />';
    }

    public function plugin_setting_dmeapikey($args)
    {
        $dmeapikey = $this->option->getOption('platforms')['dnsmadeeasy']['dmeapikey'];
        echo '<input id="' . esc_attr( $args['label_for'] ) . '" name="' . esc_attr( $args['label_for'] ) . '" type="password" value="' . esc_attr ( $dmeapikey ) . '" />';
    }

    public function plugin_setting_dmesecretkey($args)
    {
        $dmesecretkey = $this->option->getOption('platforms')['dnsmadeeasy']['dmesecretkey'];
        echo '<input id="' . esc_attr( $args['label_for'] ) . '" name="' . esc_attr( $args['label_for'] ) . '" type="password" value="' . esc_attr ( $dmesecretkey ) . '" />';
    }

    public function plugin_setting_dmedomainid($args)
    {
        $dmedomainid = $this->option->getOption('platforms')['dnsmadeeasy']['dmedomainid'];
        echo '<input id="' . esc_attr( $args['label_for'] ) . '" name="' . esc_attr( $args['label_for'] ) . '" type="text" value="' . esc_attr ( $dmedomainid ) . '" />';
    }

    public function plugin_setting_dmeserverip($args)
    {
        $dmeserverip = $this->option->getOption('platforms')['dnsmadeeasy']['dmeserverip'];
        echo '<input id="' . esc_attr( $args['label_for'] ) . '" name="' . esc_attr( $args['label_for'] ) . '" type="text" value="' . esc_attr ( $dmeserverip ) . '" />';
    }

    public function plugin_setting_dmestaging($args)
    {
        $dmestaging = $this->option->getOption('platforms')['dnsmadeeasy']['dmestaging'];
        echo '<input id="' . esc_attr( $args['label_for'] ) . '" name="' . esc_attr( $args['label_for'] ) . '" type="text" value="' . esc_attr ( $dmestaging ) . '" />';
    }

    public function plugin_options_validate($input)
    {
        $input['platforms']['dnsmadeeasy']['enabled'] = isset($input['platforms']['dnsmadeeasy']['enabled']) ? true == \sanitize_text_field($input['platforms']['dnsmadeeasy']['enabled']) : false;
        $input['platforms']['dnsmadeeasy']['dmeapiurl'] = isset($input['platforms']['dnsmadeeasy']['dmeapiurl']) ? \sanitize_text_field($input['platforms']['dnsmadeeasy']['dmeapiurl']) : null;
        $input['platforms']['dnsmadeeasy']['dmeapikey'] = isset($input['platforms']['dnsmadeeasy']['dmeapikey']) ? \sanitize_text_field($input['platforms']['dnsmadeeasy']['dmeapikey']) : null;
        $input['platforms']['dnsmadeeasy']['dmesecretkey'] = isset($input['platforms']['dnsmadeeasy']['dmesecretkey']) ? \sanitize_text_field($input['platforms']['dnsmadeeasy']['dmesecretkey']) : null;
        $input['platforms']['dnsmadeeasy']['dmedomainid'] = isset($input['platforms']['dnsmadeeasy']['dmedomainid']) ? \sanitize_text_field($input['platforms']['dnsmadeeasy']['dmedomainid']) : null;
        $input['platforms']['dnsmadeeasy']['dmeserverip'] = isset($input['platforms']['dnsmadeeasy']['dmeserverip']) ? \sanitize_text_field($input['platforms']['dnsmadeeasy']['dmeserverip']) : null;
        $input['platforms']['dnsmadeeasy']['dmestaging'] = isset($input['platforms']['dnsmadeeasy']['dmestaging']) ? \sanitize_text_field($input['platforms']['dnsmadeeasy']['dmestaging']) : null;

        return $input;
    }
}
