<?php declare(strict_types=1);
namespace DiviManagerPro\Page;

defined( 'ABSPATH' ) or die( 'Unexpected access' );

use DiviManagerPro\DiviManagerPro;
use DiviManager\Page\Create as CreatePage;
use DiviManager\Service\Site as SiteService;
use DiviManagerPro\Service\SiteCreation as SiteCreationService;
use DiviManager\Service\Profile as ProfileService;
use DiviManager\Model\Site as SiteModel;
use DiviManager\Action\Site as SiteAction;
use DiviManager\Helper;

use DiviManagerPro\Service\SiteProvision as ProvisionService;

/**
 * Page for creating a new site
 */
class Create extends CreatePage
{
    /**
     * @var DiviManagerPro $manager
     */
    protected $manager;

    /**
     * @var ProvisionService $provision
     */
    protected $provisionService;


    /**
     * Set the main manager class
     */
    public function setManagerPro(DiviManagerPro $manager)
    {
        $this->manager = $manager;
    }

    /**
     * Set the provision service
     */
    public function setProvisionService(ProvisionService $s)
    {
        $this->provisionService = $s;
    }

    public function makeProfileSelect($profileID = null)
    {
        $html =<<<EOHTML
<select name="profile" id="profile">
EOHTML;

        $option =<<<EOHTML
    <option value="%s"%s>%s</option>
EOHTML;
        foreach ($this->profileService->getProfiles() as $profile) {
            $selected = '';
            if (null !== $profileID && $profileID == $profile->getId()) {
                $selected = ' selected="selected"';
            }
            $html .= sprintf($option, $profile->getId(), $selected, $profile->getName() . ($profile->doesClone() ? ' ( Clones )' : ''));
        }

        $html .=<<<EOHTML
</select>
EOHTML;
        return $html;
    }

    /**
     * Create a new site
     */
    public function create ()
    {
        // is this access check necessary?
        if ( !current_user_can( 'manage_options' ) )  {
            wp_die( __( 'You do not have sufficient permissions to access this page.' ) );
        }

        if (isset($_POST['save']) && "Save Site" === $_POST['save']) {
            $sanitized = sanitize_text_field($_POST['url']);
            $sanitized = $this->siteService->stripSchemeFromUrl($sanitized);

            if (false === strpos($sanitized, '.')) {
                $sanitized .= '.com'; // add '.com' if no domain extension is provided
            }

            if ($this->siteService->siteExists($sanitized, SiteService::JUST_MANAGER)) {
                Helper::adminMessage(sprintf( __( '%s already exists, please try a different domain name'), $sanitized ), Helper::ERROR);
            } else {
                if (isset($_POST['provision']) && 'provision' === $_POST['provision']) {
                    $provision = true;
                } else {
                    $provision = false;
                }

                if (isset($_POST['staging'])&& 'true' == $_POST['staging']) {
                    $staging = true;
                } else {
                    $staging = false;
                }               

                if (isset($_POST['clone']) && 'clone' === $_POST['clone']) {
                    $clone = true;
                } else {
                    $clone = false;
                }

                // temporary disable cloning
                $clone = false;

                $profile = $this->profileService->getProfile(sanitize_text_field($_POST['profile']));
                $user = sanitize_text_field($_POST['user']);
                $subscription = sanitize_text_field($_POST['subscription']);
                $note = sanitize_text_field($_POST['note']);

                // the site creation service will handle the work of creating the new site and starting any provision process
                $site = $this->siteCreationService->newSite($sanitized, $profile, $user, $subscription, $note, $staging, $provision, $clone, true);

                Helper::adminMessage( __( 'Site created'), Helper::SUCCESS);

                $managerUrl = admin_url( 'admin.php?page=divimanager-menu' );
                $detailUrl = admin_url( 'admin.php?page=divimanager-site-detail&site_id=' . $site->getId() );
                echo <<<EOHTML
<p>Click to return to <a href="$managerUrl">Manager</a> or to view site <a href="$detailUrl">details</a>.</p>
EOHTML;
                return;
            }
        }

        $userSelect = \wp_dropdown_users(['echo' => false, 'selected' => null, 'show_option_none' => 'None']);
        $profileSelect = $this->makeProfileSelect();
?>
    <div class="wrap">
        <h1 class="wp-heading-inline"><?php echo esc_html( get_admin_page_title() ); ?></h1>
        <div id="post-body" class="metabox-holder columns-2">
            <div id="post-body-content">
                <div class="meta-box-sortables ui-sortable">
                    <form method="POST">
                    <table class='form-table'>
                    <tr><th>Name</th><td><input type="text" name="name" value="<?php //echo $site->getName(); ?>" /></td><td>The name of the site to manage.  It can be the domain or some other label which will identify this site when listing sites.</td></tr>
                    <tr><th>Domain</th><td><input type="text" name="url" value="<?php //echo $site->getDomain(); ?>" /></td><td>This is the domain for the website.  Manager uses this to generate the urls to communicate with the site.  And also for registering the staging domain and making staging urls.</td></tr>
                    <tr><th>Subscription ID</th><td><input type="text" name="subscription" value="<?php //echo $site->getOrderID(); ?>" /></td><td>This is woocommerce subscription ID for the site.  The subscription ID is different from individual order IDs.</td></tr>
                    <tr><th>Customer</th><td><?php echo $userSelect; ?></td><td>This is customer of the site.</td></tr>
                    <tr><th>Profile</th><td><?php echo $profileSelect; ?></td><td>Select a profile for this site.</td></tr>
                    <tr><th>Note</th><td><textarea name="note"><?php //echo $site->getNote(); ?></textarea></td><td>Any note related to the site.</td></tr>
                    <tr><th>Staging</th><td><input type="checkbox" name="staging" value="true" \></td><td>Is the site in staging or production?</td></tr>
                    <tr><th>PROVISION</th><td><input type="checkbox" name="provision" value="provision" \></td><td>Should this site be created on the host service?  If unchecked, the site is only added to Manager.  If checked, Manager will atempt to create the site, using the selected profile.
                    <tr><th>CLONE</th><td><input type="checkbox" name="clone" value="clone" \></td><td>If the profile is setup for cloning, Manager will attempt to clone to the new site.</td></tr>
                    </table>
                    <button type="submit" name="save" value="Save Site">Save Site</button>
                    <button type="reset" name="reset" value="Reset">Reset</button>
                    </form>
                </div>
            </div>
        </div>
        <br class="clear">
	</div>
<?php
    }
}
