<?php declare(strict_types=1);
namespace DiviManagerPro\Page;

defined( 'ABSPATH' ) or die( 'Unexpected access' );

use DiviManager\Helper;
use DiviManagerPro\Service\SiteProvision as ProvisionService;

/**
 * Display site provision information
 */
class Provision
{
    protected $serverService;
    protected $mainPluginFile;

    public function __construct(
        ProvisionService $provisionService,
        $mainPluginFile
    ) {
        $this->setProvisionService($provisionService);
        add_action( 'admin_enqueue_scripts', [$this, 'enqueue_scripts'] );
        $this->mainPluginFile = $mainPluginFile;
    }

    public function setProvisionService(ProvisionService $s)
    {
        $this->provisionService = $s;
    }

    /**
     * Enqueue javascript for pages
     *
     * https://developer.wordpress.org/plugins/javascript/enqueuing/
     */
    public function enqueue_scripts($hook)
    {
        if ('manager_page_divimanager-provision' === $hook) {
            if( ! \wp_script_is( 'provision.js', 'registered' ) ){
                $this->register_scripts($hook);
            }

            \wp_enqueue_script( 'form.js' );
            \wp_enqueue_script( 'provision.js' );
        }
    }

    /**
     * Register our scripts so wordpress knows about them
     */
    public function register_scripts($hook)
    {
        \wp_register_script(
            'provision.js',
            \plugins_url( '/js/provision.js', $this->mainPluginFile ),
            [ 'jquery' ],
            '1.0.0',
            [
               'in_footer' => true,
            ]
        );

        \wp_localize_script(
            'provision.js',
            'DMPROprovision', [
                'strings' => [
                    'saved' => __( 'Provision Saved', 'text-domain' ),
                    'error' => __( 'Error', 'text-domain' )
                ],
                'api'     => [
                    'url'   => esc_url_raw( rest_url( 'dmpro/v1/provisions' ) ),
                    'nonce' => wp_create_nonce( 'wp_rest' )
                ]
            ]
        );
    }

    /**
     * Main page
     */
    public function index ()
    {
?>
    <div class="wrap">
        <h1 class="wp-heading-inline"><?php echo esc_html( get_admin_page_title() ); ?></h1>
<?php
        $this->provisions();
?>
    </div>
<?php
    }

    /**
     * Show provisions
     */
    public function provisions ()
    {
        echo <<<EOHTML
    <div class="wrap">
        <h1 class="wp-heading-inline"><?php echo esc_html( get_admin_page_title() ); ?></h1>
        <p>DiviManager tracks the site provisions requested</p>
EOHTML;
?>
        <div id="feedback">
        </div>
        <p>Following site provisions have been requests.</p>
        <form id="provision">
            <table id="provisions" class="form-table">
                <thead>
                <tr>
                    <th></th>
                    <th>Site</th>
                    <th>Status</th>
                </tr>
                </thead>
                <tbody>
                </tbody>
            </table>
        </form>
    </div>
<?php
    }
}
