<?php declare(strict_types=1);
namespace DiviManagerPro\Reporter\Command;

use DiviManagerPro\Reporter\Action\Reporter as ReporterAction;
use DiviManagerPro\Reporter\Service\Reporter as ReporterService;
use DiviManager\Service\Site as SiteService;
use DiviManager\DiviManager;

/**
 * Generate reports for managed sites
 */
class Report extends \WP_CLI_Command
{
    public function setSiteService(SiteService $sm)
    {
        $this->siteService = $sm;
    }

    public function setReporterAction(ReporterAction $r)
    {
        $this->reporterAction = $r;
    }

    public function setReporterService(ReporterService $r)
    {
        $this->reporterService = $r;
    }

    /**
     * Fetch the report data from a remote site
     * Helpful for testing
     *
     * ## OPTIONS
     *
     * <site_id>
     * : The id of the site to generate the report.
     *
     * [--send]
     * : To send the reports email..
     *
     * [--email=<email>]
     * : Email to send the report, useful for testing.
     *
     *
     * ## EXAMPLES
     *
     *     wp manager report <site_id> [--send=<send>] [--email=<email>]
     *
     * @subcommand report
     */
    public function report($args, $assoc_args )
    {
        $siteID = $args[0];
        $send = isset($assoc_args['send']) ? $assoc_args['send'] : false;
        $email = isset($assoc_args['email']) ? $assoc_args['email'] : null;

        $site = $this->siteService->getSite($siteID);
        if (null === $site) {
            \WP_CLI::error( 'Site not found' );
        }

        if (true === $send) {
            \WP_CLI::log( 'Sending report email' );
            $this->reporterAction->sendReport($site, $email);
        }

        $subject = $this->reporterService->subjectForSite($site); 
        $email = $this->reporterService->emailBodyForSite($site); 
        \WP_CLI::log( print_r($subject, true) );
        \WP_CLI::log( print_r($email, true) );
        \WP_CLI::success( 'Success' );
    }
}
