<?php declare(strict_types=1);
namespace DiviManagerPro\Reporter;

use DiviManager\Helper\Option as Option;

/**
 * Handle cron actions
 */
class Cron
{
    public function setOption(Option $option)
    {
        $this->option = $option;
    }

    public function setReporter(Reporter $r)
    {
        $this->reporter = $r;
    }

    /**
     * Check if this is the last day of the month
     * What if the last day is skipped?
     * Meaning the website is not accessed on the last day of the month.  The next time the site is accessed may be the next month, so one month will be skipped
     *
     * Trigger daily.
     * Check if we have run this month.
     * When run, use the previous month as the target.
     */
    public function cronDailyReport ()
    {
        if ($this->reporter->isReporterEnabled()) {
            // TBD:: should have some measure of mutex on this
            $lastRun = $this->option->getOption('report_last_run');

            $targetMonth = new \Datetime;
            $targetMonth->modify('last day of last month');

            if ($lastRun instanceof \Datetime) {
                if ($targetMonth->format('Y-m') == $lastRun->format('Y-m')) {
                    // already ran report for last month
                    // do nothing
                    return;
                }
            }

            // report has not been run for the last month
            // set the last month value, so we do not double run
            $this->option->setOption('report_last_run', $targetMonth);
            $this->reporter->setTargetMonth($targetMonth);

            // send the email report
            $this->reporter->email();
        }
    }
}
