<?php declare(strict_types=1);
namespace DiviManagerPro\Reporter\Page;

defined( 'ABSPATH' ) or die( 'Unexpected access' );

use DiviManagerPro\DiviManagerPro;
use DiviManager\Service\Site as SiteService;
use DiviManagerPro\Reporter\Service\Reporter as ReporterService;
use DiviManagerPro\Reporter\Action\Reporter as ReporterAction;
use DiviManager\Helper;

/**
 * Show sample report for page
 */
class Report
{
    /**
     * @var Option options manager
     */
    protected $option;

    /**
     * @var DiviManagerPro the reporter extension main class
     */
    protected $reporter;

    /**
     * @var SiteService
     */
    protected $siteService;

    /**
     * @var ReporterAction
     */
    protected $reporterAction;

    /**
     * @var ReporterService
     */
    protected $reporterService;

    public function __construct()
    {
    }

    public function setOption($option)
    {   
        $this->option = $option;
    }

    public function setDiviManagerPro(DiviManagerPro $r)
    {
        $this->reporter = $r;
    }

    public function setSiteService(SiteService $s)
    {
        $this->siteService = $s;
    }

    public function setReporterService(ReporterService $r)
    {
        $this->reporterService = $r;
    }

    public function setReporterAction(ReporterAction $r)
    {
        $this->reporterAction = $r;
    }

    /**
     * Show current report for website
     */
    public function report ()
    {
        if (! isset($_GET['site_id'])) {
            echo <<<EOHTML
<p>No site was specified.</p>
EOHTML;
            return;
        }

        $site_id = \sanitize_text_field($_GET['site_id']);
        $site = $this->siteService->getSite($site_id);

		if (null === $site) {
			echo <<<EOHTML
			<p>Site not found</p>
EOHTML;
			return;
        }

        $options = get_option($this->reporter::OPTIONS_NAME);
        $to = $this->option->getOption('report_email');
        $cc = $this->option->getOption('report_cc');
        $subject = $this->reporterService->subjectForSite($site);
        $emailBody = $this->reporterService->emailBodyForSite($site);
        $lastRunDate = $options['report_last_run'];
        //if (! $lastRunDate instanceof \Datetime) {
            //$timestamp = wp_next_scheduled( DiviManagerPro::CRON_HOOK );
            //$nextReportDate = new \Datetime;
            //$nextReportDate->setTimestamp($timestamp);
            //$lastRunMessage = 'The report has not yet been run.  The report is scheduled to run on: ' . $nextReportDate->format('Y-m-d');

        //} else {
            $lastRunMessage = $lastRunDate;//->format('Y-m-d');
        //}

        echo <<<EOHTML
<p>The report was last run for the month ending:$lastRunMessage.</p>
<p>The report will be sent to: $to</p>
<p>The report will be Cc'd: $cc</p>
<p>The following are what the processed shortcodes will look like for this site:</p>
<p>The email subject will be: $subject</p>
<p>The following is what the email would look like.</p>
<div style="border: 1px black solid;">$emailBody</div>
<p>To send the report please click the Send button below.</p>
<form method="POST">
<input type="submit" name="send_email" value="Send" />
</form>
EOHTML;

        if (isset($_POST['send_email']) && $_POST['send_email']) {
            $ok = $this->reporterAction->sendReport($site);

            if (! $ok) {
                Helper::adminMessage('Email not sent', Helper::ERROR);
            } else {
                Helper::adminMessage('Email Sent', Helper::SUCCESS);
            }
        }


        $codes = $this->reporterService->getContentCodes();
        $html = <<<EOHTML
        <hr />
        <h2>Shortcodes</h2><p>These are the shortcodes as would be processed for this site.</p>
<table>
<thead>
<tr><th>Section</th><th>Shortcode</th><th>Description</th><th>Content</th></tr>
</thead>
<tbody>
EOHTML;
        foreach ($codes as $section => $details) {
            $html .= sprintf('<tr><td colspan=4 style="border: 1px black solid;">%s</td></tr>', $section);
            //$reportClass = $details['class'];
            //$reportContentClass = new $reportClass;
            foreach ($details['content'] as $code => $description) {
                $content = do_shortcode('[' . $code.']');
                $html .= sprintf('<tr><td style="border: 1px black solid;">%s</td><td style="border: 1px black solid;">%s</td><td style="border: 1px black solid;">%s</td><td style="border: 1px black solid;">%s</td></tr>', '', $code, $description, $content);
            }
        }


        $html .=<<<EOHTML
</tbody>
</table>
EOHTML;

        echo $html;
        //echo '<hr /><pre>';var_dump($site->getData()->report);echo '</pre>';
        //return;
    }
}
