<?php declare(strict_types=1);
namespace DiviManagerPro\Reporter\Service;

defined( 'ABSPATH' ) or die( 'Unexpected access' );

use DiviManager\Registry;
use DiviManager\Action\AbstractAction;
use DiviManager\Service\Site as SiteService;
use DiviManager\Helper\Option;
use DiviManagerPro\Service\DiviManagerPro;

/**
 * Send a report for a site
 */
class Email extends AbstractAction
{
    /**
     * @var String default email template
     */
    public $template = null;

    public function setSiteService(SiteService $sm)
    {
        $this->siteService = $sm;
    }

    public function setOption(Option $sm)
    {
        $this->option = $sm;
    }

    public function setReporter(Reporter $r)
    {
        $this->reporter = $r;
    }

    /**
     * send the report email
     *
     * @see https://sendgrid.com/docs/for-developers/sending-email/wordpress-plugin/
     */
    public function sendReport ($site, $email = null)
    {
        // initialize the shortcodes with the target site
        $codes = $this->reporter->getShortcodes();
        foreach ($codes as $section => $code) {
            $code->setSite($site);
        }

        $options = $this->option->getOptions();
        $to = $options['report_email'];
        $cc = $options['report_cc'];
        if (null !== $email) {
            $to = $email;
            $cc = null;
        }
        $subject = $this->reporter->subjectForSite($site);
        $emailBody = $this->reporter->emailBodyForSite($site);
        $headers = [
            'Content-Type: text/html; charset=UTF-8',
        ];

        if (null !== $cc && ! empty($cc)) {
            $headers[] = 'Cc: ' . $cc;
        }

        add_filter( 'wp_mail_content_type', [$this, 'set_html_content_type'] );
        $ok = wp_mail ( $to, $subject, $emailBody, $headers );
        remove_filter( 'wp_mail_content_type', [$this, 'set_html_content_type'] );

        return $ok;
    }

    public function set_html_content_type ()
    {
        return 'text/html';
    }
}
