<?php declare(strict_types=1);
namespace DiviManagerPro\Reporter\Service;

defined( 'ABSPATH' ) or die( 'Unexpected access' );

use DiviManager\Registry;
use DiviManager\Service\Site as SiteService;
use DiviManager\Helper\Option;
use DiviManagerPro\Reporter as DMReporter;

/**
 * Handle the actual business of shortcodes, template, and generating reports
 */
class Reporter
{
    /**
     * @var array our shortcodes
     */
    public $shortcodes = [];

    public function setScPrefix($s)
    {
        $this->scPrefix = $s;
    }

    public function setOption(Option $o)
    {
        $this->option = $o;
    }

    /**
     * On initialization, need to cause all our shortcodes to register with wordpress
     */
    public function init()
    {
        $this->codes = [];
        foreach ($this->getShortcodes() as $key => $code) {
            $codes[$key] = ['content' => []];
            foreach ($code->getCodes() as $detail) {
                $sc = $this->scPrefix.'.'.$key.'.'.$detail['code'];
                $this->codes[$key]['content'][$sc] = $detail['label'];
                add_shortcode($sc, $detail['callable']);
            }
        }
    }

    public function addShortcode($key, $code)
    {
        $this->shortcodes[$key] = $code;
    }

    public function getShortcodes()
    {
        return $this->shortcodes;
    }

        //$actions = [
        //];
        //return \apply_filters ($this->hookPrefix . '_reporter_shortcodes', $actions);
        //\add_filter ($this->reporter->hookPrefix . '_reporter_shortcodes', [$this, 'myColumns'], 1, 1);
    /**
     * Return data structure of supported report content
     */
    public function getContentCodes()
    {
        return $this->codes;
    }

    /**
     * initialize the shortcodes with the target site
     */
    public function initializeShortcodesForSite($site)
    {
        $codes = $this->getShortcodes();
        foreach ($codes as $section => $code) {
            $code->setSite($site);
        }
    }

    public function subjectForSite($site)
    {
        $this->initializeShortcodesForSite($site);
        $subject = $this->option->getOption('report_subject');
        if (null === $subject || empty($subject)) {
            // use a default
            $subject = $site->getName() . ' Status Report';
        }

        $subject = do_shortcode($subject);

        return $subject;
    }

    public function emailBodyForSite($site)
    {
        $this->initializeShortcodesForSite($site);
        $template = $this->option->getOption('report_template');
        if (null === $template || empty($template)) {
            // use our plain default
            $templateFile = WP_PLUGIN_DIR . '/divimanager-pro/templates/email.phtml';
            //$templateFile = __DIR__ . '/../../templates/email.phtml';
            $template = file_get_contents($templateFile);
        }

        // get the report body
        return do_shortcode($template, true);
    }

}
