<?php declare(strict_types=1);
namespace DiviManagerPro\Reporter\Shortcode;

defined( 'ABSPATH' ) or die( 'Unexpected access' );

use DiviManagerPro\DiviManagerPro;
use DiviManager\Model\Site;
use DiviManagerPro\Reporter\Reporter;

/**
 * Abstract base class for our shortcodes
 */
abstract class AbstractShortcode
{
    /**
     * @var DiviManagerPro
     * Instance of the main class
     */
    public $divimanager;

    /**
     * @var Reporter
     * Instance of the Reporter class
     */
    public $reporter;

    /**
     * @var Site the site to process this shortcode for
     */
    public $site;

    public function setDiviManagerPro(DiviManagerPro $r)
    {
        $this->divimanager = $r;
    }

    public function setReporter(Reporter $r)
    {
        $this->reporter = $r;
    }

    public function setSite(Site $site)
    {
        $this->site = $site;
    }

    public $shortcodes = [];

    public function getCodes()
    {
        return $this->shortcodes;
    }

    // Should the shortcode we return include HTML/CSS?
    const IS_HTML = false;
    
    // Add shortcode to array
    public function addCode($code, $label, $callable)
    {
        if (is_callable($callable))
        {
            $this->shortcodes[$code] = ['code' => $code, 'label' => $label, 'callable' => $callable];
        } 
        else
        {   
            // Create a function from the array in $callable
            $createCallable = function() use ($callable)
            {
                $data = $this->site->getData();
                $returnData = $data;
                $dataLoop = [];
                
                foreach ($callable as $key)
                {   
                    if (!is_array($key)) {
                        $returnData = $returnData[$key];
                    } else {
                        $dataLoop = $key;
                    }
                }

                $returnString = '';
                if (is_array($returnData))
                {
                    for ($i = 0; $i < count($returnData); $i++)
                    {
                        foreach ($dataLoop as $key)
                        {
                            $returnString = "$returnString " . $returnData[$i][$key];
                        }
                    }
                }

                if($returnString === '')
                {
                    $returnString = $returnData;
                }

                return "$returnString";
            };

            $this->shortcodes[$code] = ['code' => $code, 'label' => $label, 'callable' => $createCallable];
        }
    }
}
