<?php declare(strict_types=1);
namespace DiviManagerPro\Reporter\Shortcode;

defined( 'ABSPATH' ) or die( 'Unexpected access' );

/**
 * Aggregate google analytic data from Monster Insights
 */
class MonsterInsight extends AbstractShortcode
{
    public function __construct()
    {
        $this->addCode('stats', 'Single block for MonsterInsights analytics stats', [$this, 'stats']);
        $this->addCode('sessions', 'MonsterInsights sessions', ['report', 'monsterinsight', 'data', 'infobox', 'sessions', 'value']);
        $this->addCode('pageviews', 'MonsterInsights page views', ['report', 'monsterinsight', 'data', 'infobox', 'pageviews', 'value']);
        $this->addCode('totalusers', 'MonsterInsights total users', ['report', 'monsterinsight', 'data', 'infobox', 'totalusers', 'value']);
        $this->addCode('duration', 'MonsterInsights Duration', ['report', 'monsterinsight', 'data', 'infobox', 'duration', 'value']);
    }

    public function stats()
    {
        $data = $this->site->getData();
        $monster = $data['report']['monsterinsight'];

        if ('N/A' === $monster) {
            return 'Monster is not installed or activated';
        }

        if (true == $monster['success']) {
            $stats = $monster['data']['infobox'];
            $sessions = $stats['sessions']['value'];
            $pageviews = $stats['pageviews']['value'];
            $totalusers = $stats['totalusers']['value'];
            $duration = $stats['duration']['value'];
            $html = <<<EOHTML
            <style>
                .monsterinsights-report-infobox-row {
                    display: flex;                  
                    flex-flow: wrap;
                    margin: 0 20px 20px;
                    -ms-flex-flow: wrap;
                    width: 30%;
                    box-sizing: border-box;
                }

                .monsterinsights-report-header {
                    width: 100%;
                    margin-bottom: 0;
                    position: relative;
                    top: 20px;
                    text-align: center;
                }

                .monsterinsights-report-infobox-row .monsterinsights-reports-infobox {
                    width: 50%;
                    background: #fff;
                    border: 1px solid #d6e2ed;
                    padding: 17px 20px 15px;
                    position: relative;
                    -webkit-box-sizing: border-box;
                    box-sizing: border-box;
                }
                
                .monsterinsights-report-infobox-row .monsterinsights-reports-infobox .monsterinsights-report-title {
                    padding-right: 18px;
                    text-overflow: ellipsis;
                    overflow: hidden;
                    white-space: pre;
                    line-height: 1.2;
                }

                .monsterinsights-report-title {
                    font-size: 16px;
                    color: #393f4c;
                    font-weight: 700;
                    margin-top: 0;
                }

                .monsterinsights-reports-infobox-number {
                    font-size: 36px;
                    font-weight: 200;
                    display: inline-block;
                    line-height: 1;
                    margin-top: 11px;
                    float: left;
                    font-family: Helvetica Neue,Helvetica,Arial,Lucida Grande,sans-serif;
                }
            </style>
            <div class="activity-block">
                <div class="monsterinsights-report-infobox-row" style="width: 60%">
                    <div class="monsterinsights-reports-infobox monsterinsights-report-header">
                        <h1>MonsterInsights Analytics</h1>
                    </div>
                </div>
                <div class="monsterinsights-report-infobox-row">
                    <div class="monsterinsights-reports-infobox">
                        <div class="monsterinsights-report-title">Sessions</div>
                        <div title="$sessions" class="monsterinsights-reports-infobox-number">$sessions</div>
                    </div>
                    <div class="monsterinsights-reports-infobox">
                        <div class="monsterinsights-report-title">Pageviews</div>
                        <div title="$pageviews" class="monsterinsights-reports-infobox-number">$pageviews</div>
                    </div>
                    <div class="monsterinsights-reports-infobox">
                        <div class="monsterinsights-report-title">Avg. Session Duration</div>
                        <div title="$duration" class="monsterinsights-reports-infobox-number">$duration</div>
                    </div>
                    <div class="monsterinsights-reports-infobox">
                        <div class="monsterinsights-report-title">Total Users</div>
                        <div title="$totalusers" class="monsterinsights-reports-infobox-number">$totalusers</div>
                    </div>
                </div>
            </div>
EOHTML;
            return $html;
        } else {
            return 'MonsterInsights is not authenticated';
        }

    }
}
