<?php declare(strict_types=1);
namespace DiviManagerPro\Reporter\Shortcode;

defined( 'ABSPATH' ) or die( 'Unexpected access' );

/**
 * Woocommerce report information
 *
 * see woocommerce/includes/admin/class-wc-admin-dashboard.php
 */
class WcReport extends AbstractShortcode
{
    public function __construct()
    {
        $this->addCode('status', 'Single block of WC data', [$this, 'status']);
        $this->addCode('sales.net', 'Net sales', ['report', 'wc', 'net']);
        $this->addCode('orders.processing', 'Count of orders processing', ['report', 'wc', 'processing']);
        $this->addCode('orders.hold', 'Count of orders on hold', ['report', 'wc', 'onhold']);
        $this->addCode('products.low', 'Count of products low in stock', ['report', 'wc', 'low']);
        $this->addCode('products.out', 'Count of products out of stock', ['report', 'wc', 'out']);
        $this->addCode('db.check', 'Does the woocommerce db require an update', ['report', 'wc', 'db']);
    }

    /**
     * Single block for woocommerce status
     */
    public function status()
    {
        $data = $this->site->getData();
        $wc = $data['report']['wc'];

        if ('N/A' === $wc) {
            return 'Woocommerce is not installed or activated';
        }

        $contentHTML =<<<EOHTML
        <p>Net sales this month: {$wc['net']}</p>
        <p>Orders processing: {$wc['processing']}</p>
        <p>Orders on hold: {$wc['onhold']}</p>
        <p>Products low in stock: {$wc['low']}</p>
        <p>Products out of stock: {$wc['out']}</p>
        EOHTML;
        return $contentHTML;
    }
}
