<?php declare(strict_types=1);
namespace DiviManagerPro\Rest;

defined( 'ABSPATH' ) or die( 'Unexpected access' );

use DiviManager\Helper\Option;
use DiviManager\Service\Theme as ThemeService;
use DiviManagerPro\Integration\Setting as IntegrationSetting;
use WP_REST_Request;
use WP_REST_Server;
use WP_REST_Controller;

/**
 * REST api for divimanager-pro
 *
 * This is the base api.  Other services will add their own api
 *
 * @see https://developer.wordpress.org/rest-api/extending-the-rest-api/adding-custom-endpoints/
 * @see https://torquemag.io/2017/06/creating-wordpress-settings-page-using-wordpress-rest-api/
 */
class DiviManagerPro extends WP_REST_Controller
{
    /**
     * @var String
     */
    protected $base;

    public function __construct($base)
    {
        $this->setBase($base);
    }

    public function getBase()
    {
        return $this->base;
    }

    public function setBase($base)
    {
        $this->base = $base;
    }

    public function init()
    {
        add_action( 'rest_api_init', [$this, 'register_rest_routes']);
    }

    /**
     * Register our rest routes with the REST endpoint
     */
    public function register_rest_routes()
    {
        // post settings
        register_rest_route( $this->base, '/settings', [
            'methods' => WP_REST_Server::CREATABLE,
            'callback' => [$this, 'update'],
            'args' => [
                'industry' => [
                    'type' => 'string',
                    'required' => false,
                    'sanitize_callback' => 'sanitize_text_field'
                ],
                'amount' => [
                    'type' => 'integer',
                    'required' => false,
                    'sanitize_callback' => 'absint'
                ]
            ],
            'permission_callback' => [$this, 'permissions'],
        ]);
    }

    /**
     * Update setting values
     */
    public function update(WP_REST_Request $request)
    {
        $integrationID = $request->get_param('integration');
        $integration = $this->integrationService->integration($integrationID);
        $integration->updateSettings($request->get_params());
        return rest_ensure_response( $integration->getSettings() );
    }

    /**
     * Check if access is allowed on the endpoint
     *
     * @return bool
     */
    public function permissions()
    {
        // make sure the user can manage options
        return current_user_can( 'manage_options' );
    }
}
