<?php declare(strict_types=1);
namespace DiviManagerPro\Rest;

defined( 'ABSPATH' ) or die( 'Unexpected access' );

use DiviManager\Helper\Option;
use WP_REST_Request;
use WP_REST_Server;
use WP_REST_Controller;

/**
 * api support for the forms
 * Provides the metadata for the frontend to build the form
 */
class Form extends WP_REST_Controller
{
    /**
     * @var String
     */
    protected $base;

    public function __construct($base)
    {
        $this->setBase($base);

        $this->forms = [];
    }

    public function getBase()
    {
        return $this->base;
    }

    public function setBase($base)
    {
        $this->base = $base;
    }

    public function addForm($name, $form)
    {
        $this->forms[$name] = $form;
    }

    public function init()
    {
        add_action( 'rest_api_init', [$this, 'register_rest_routes']);
    }

    /**
     * Register our rest routes with the REST endpoint
     */
    public function register_rest_routes()
    {
        // get settings
        register_rest_route( $this->base, '/form/(?P<form>\w+)', [
            'methods' => WP_REST_Server::READABLE,
            'callback' => [$this, 'getForm'],
            'args' => [
                'profile' => [
                    'type' => 'string',
                    'required' => false,
                    'sanitize_callback' => 'sanitize_text_field'
                ],
            ],
            'permission_callback' => [$this, 'permissions'],
        ]);
        register_rest_route( $this->base, '/', [
            'methods' => WP_REST_Server::READABLE,
            'callback' => [$this, 'getList'],
            'permission_callback' => [$this, 'permissions'],
        ]);
    }

    /**
     * Return the form settings
     */
    public function getForm(WP_REST_Request $request)
    {
        $form = sanitize_text_field( $request->get_param('form') );
        if (isset($this->forms[$form])) {
            return rest_ensure_response( $this->forms[$form]->getForm() );
        }

        throw new \Exception('No form found for name: ' . $form);
    }

    /**
     * Check if access is allowed on the endpoint
     *
     * @return bool
     */
    public function permissions()
    {
        // make sure the user can manage options
        return current_user_can( 'manage_options' );
    }
}
