<?php declare(strict_types=1);
namespace DiviManagerPro\Rest;

defined( 'ABSPATH' ) or die( 'Unexpected access' );

use DiviManagerPro\Service\SiteProvision as ProvisionService;

/**
 * REST api for managing provisions
 */
class Provision
{
    /**
     * @var String
     */
    protected $base;

    /**
     * @var ProvisionService
     */
    protected $provisionService;


    public function __construct(
        $base,
        ProvisionService $provisionService
    ) {
        $this->setBase($base);
        $this->setProvisionService($provisionService);
    }

    public function getBase()
    {
        return $this->base;
    }

    public function setBase($base)
    {
        $this->base = $base;
    }

    public function setProvisionService(ProvisionService $s)
    {
        $this->provisionService = $s;
    }

    public function init()
    {
        add_action( 'rest_api_init', [$this, 'register_rest_routes']);
    }

    public function register_rest_routes()
    {
        // provision routes
        register_rest_route( $this->base, '/provisions', [
            [
                'methods' => \WP_REST_Server::READABLE,
                'callback' => [$this, 'getList'],
                'permission_callback' => [$this, 'verifyToken'],
            ]
        ]);
        register_rest_route( $this->base, '/provisions/(?P<id>[\d]+)', [
            [
                'methods' => \WP_REST_Server::READABLE,
                'callback' => [$this, 'get'],
                'permission_callback' => [$this, 'verifyToken'],
            ],
            [
                'methods' => \WP_REST_Server::DELETABLE,
                'callback' => [$this, 'deleteProvision'],
                'permission_callback' => [$this, 'verifyToken'],
            ]
        ]);
    }

    /**
     * Check that the request has a valid token
     *
     * @return null|WP_Error null if valid, WP_Error if invalid
     */
    public function verifyToken($request = null)
    {
        // from wp-includes/rest-api/endpoints/class-wp-rest-plugins-controller.php
        if ( ! current_user_can( 'administrator' ) ) {
            return new \WP_Error(
                'rest_cannot_view_servers',
                __( 'Sorry, you are not allowed to manage site provisions.' ),
                array( 'status' => rest_authorization_required_code() )
            );
        }

        return true;
    }

    /**
     * Return the provisions
     */
    public function getList($request)
    {
        $provisions = $this->provisionService->getRecords();
        $data = [];
        foreach ($provisions as $provision) {
            $data[] = $provision->toArray();
        }

        return new \WP_REST_Response($data);
    }

    /**
     * Delete an existing provision
     */
    public function deleteProvision($request)
    {
        $params = $request->get_params();
        $provision = $this->provisionService->getRecord($params['id']);

        if (null === $provision) {
            return new \WP_REST_Response(false);
        }

        $this->provisionService->deleteProvision($provision);
        return new \WP_REST_Response(true);
    }
}
