<?php declare(strict_types=1);
namespace DiviManagerPro\Service;

defined('ABSPATH') or die('Unexpected access');

/**
 * Keep track of the available integrations
 */
class Integration
{
    /**
     * @var array integrations registered with the manager
     */
    protected $integrations = [];

    public function __construct()
    {
    }

    /**
     * Return the currently registered integrations
     */
    public function integrations()
    {
        return $this->integrations;
    }

    /**
     * Return integrations with the ids
     */
    public function getIntegrationsByID (array $ids)
    {
        $integrations = [];
        foreach ($this->integrations as $integration) {
            if (in_array($integration->getId(), $ids)) {
                $integrations[] = $integration;
            }
        }
        return $integrations;
    }

    /**
     * Return all integrations for the matching type
     */
    public function integrationsWithType($type)
    {
        return array_filter($this->integrations, function($v, $k) use ($type) {
            return $type == $v->getType();
        }, ARRAY_FILTER_USE_BOTH);
    }

    /**
     * Register an integration with the manager
     */
    public function register($integration)
    {
        $this->integrations[$integration->getId()] = $integration;
    }

    /**
     * Get a specific registered integration
     */
    public function integration($integration_id)
    {
        if (isset($this->integrations[$integration_id])) {
            return $this->integrations[$integration_id];
        }

        return null;
    }
}
