<?php declare(strict_types=1);
namespace DiviManagerPro\Service;

use DiviManager\Service\DbManager;
use DiviManagerPro\Model\Server as ServerModel;
use DiviManager\Model\Profile as ProfileModel;
use DiviManagerPro\Service\Server as ServerService;
use DiviManager\Service\Profile as ProfileService;

/**
 * Service class for working with profile server joins
 */
class ProfileServer extends DbManager
{
    /**
     * @var ProfileService;
     */
    protected $profileService;

    /**
     * @var ServerService
     */
    protected $serverService;

    public function __construct()
    {
        $fields =<<<EOSQL
profile_id varchar(64) null,
server_id int NOT NULL
EOSQL;

        parent::__construct('divimanager_pro_profile_server', $fields);
    }

    /**
     * Set the profile service
     */
    public function setProfileService(ProfileService $p)
    {
        $this->profileService = $p;
    }

    /**
     * Set the server service
     */
    public function setServerService(ServerService $s)
    {
        $this->serverService = $s;
    }

    /**
     * Get server for given profile
     *
     * @param Profile
     * @return array
     */
    public function getServerForProfile( ProfileModel $profile )
    {
        $ids = $this->getFieldByField('server_id', ['profile_id' => $profile->getID()]);

        if (null === $ids) {
            return [];
        }

        return $this->serverService->getServersByID($ids);
    }

    /**
     * Add server to profile
     *
     * @param ServerModel
     * @param ProfileModel
     */
    public function addServerToProfile( ServerModel $server, ProfileModel $profile)
    {
        $this->wpdb->insert(
            $this->getTableName(),
            [
                'profile_id' => $profile->getId(),
                'server_id' => $server->getId(),
            ],
            [
                '%s',
                '%d',
            ]
        );
    }

    /**
     * Remove server from profile
     *
     * @param ServerModel
     * @param ProfileModel
     */
    public function removeServerFromProfile( ServerModel $server, ProfileModel $profile)
    {
        $this->wpdb->delete(
            $this->tableName,
            [
                'profile_id' => $profile->getId(),
                'server_id' => $server->getId(),
            ],
            [
                '%s',
                '%d',
            ]
        );
    }
}
