<?php declare(strict_types=1);
namespace DiviManagerPro\Service;

defined('ABSPATH') or die('Unexpected access');

use DiviManager\Service\SiteCreation as SiteCreationService;
use DiviManager\Service\Queue;
use DiviManagerPro\Action\SiteProvision as SiteProvisionAction;

/**
 * Keep track of the available integrations
 */
class SiteCreation extends SiteCreationService
{
    /**
     * @var SiteProvision the provision service
     */
    protected $provisionService;

     /**
     * @var Queue the queue service
     */
    protected $queueService;

    public function setProvisionService(SiteProvision $provisionService) {
        $this->provisionService = $provisionService;
        return $this;
    }

    public function setQueueService(Queue $queueService) {
        $this->queueService = $queueService;
        return $this;
    }

    /**
     * create a new site
     * Used by ecommerce extensions
     * also can be manually triggered to add new sites without orders
     * Can clone an existing site into the new site
     */
    public function newSite($url, $profile, $user, $subscription, $note, $staging = true, $provision = false, $clone = false, $refresh = true)
    {
        error_log(
            __CLASS__.':'.__FUNCTION__ .
            print_r( ['url' => $url, 'profile' => $profile, 'provision' => true === $provision, 'clone' => true === $clone], true)
        );

        // make the new site entry in manager, using the core divimanager logic
        $site = parent::newSite($url, $profile, $user, $subscription, $note, $staging, false);

        if ($provision) {
            $newProv = $this->provisionService->newModel();
            $newProv->setStatus(SiteProvisionAction::STATUS_NEW);
            $newProv->setSiteID($site->getId());
            $newProv = $this->provisionService->createSiteProvision($newProv);

            $this->queueService->addEventForSiteToQueue(\DiviManagerPro\Action\SiteProvision::ACTION, $site, ['status' => SiteProvisionAction::STATUS_NEW]);
        }

        return $site;
    }
}
