<?php declare(strict_types=1);
namespace DiviManagerPro\Service;

use DiviManager\Service\DbManager;
use DiviManagerPro\Model\Server as ServerModel;
use DiviManager\Model\Site as SiteModel;
use DiviManagerPro\Service\Server as ServerService;
use DiviManager\Service\Site as SiteService;

/**
 * Service class for working with site server joins
 */
class SiteServer extends DbManager
{
    /**
     * @var SiteService;
     */
    protected $siteService;

    /**
     * @var ServerService
     */
    protected $serverService;

    public function __construct(
        SiteService $siteService,
        ServerService $serverService
    ) {
        $fields =<<<EOSQL
site_id int not null,
server_id int NOT NULL
EOSQL;

        parent::__construct('divimanager_pro_sites_servers', $fields);

        $this->setSiteService($siteService);
        $this->setServerService($serverService);
    }

    /**
     * Set the site service
     */
    public function setSiteService(SiteService $p)
    {
        $this->siteService = $p;
    }

    /**
     * Set the server service
     */
    public function setServerService(ServerService $s)
    {
        $this->serverService = $s;
    }

    /**
     * Get server for given site
     *
     * @param Site
     * @return array
     */
    public function getServerForSite( SiteModel $site )
    {
        $ids = $this->getFieldByField('server_id', ['site_id' => $site->getID()]);

        if (null === $ids) {
            return [];
        }

        return $this->serverService->getServersByID($ids);
    }

    /**
     * Add site to server
     *
     * @param SiteModel
     * @param ServerModel
     */
    public function addSiteToServer( SiteModel $site, ServerModel $server)
    {
        $this->wpdb->insert(
            $this->getTableName(),
            [
                'site_id' => $site->getId(),
                'server_id' => $server->getId(),
            ],
            [
                '%s',
                '%d',
            ]
        );
    }

    /**
     * Remove site from server
     *
     * @param SiteModel
     * @param ServerModel
     */
    public function removeSiteFromServer( SiteModel $site, ServerModel $server)
    {
        $this->wpdb->delete(
            $this->tableName,
            [
                'site_id' => $site->getId(),
                'server_id' => $server->getId(),
            ],
            [
                '%s',
                '%d',
            ]
        );
    }

    /**
     * Get all sites for a server
     *
     * @param ServerModel
     *
     * @return array
     */
    public function getSitesForServer(ServerModel $server)
    {
        return $this->getRecordByField('server_id', $server->getID(), '%d');
    }
}
