<?php declare(strict_types=1);
namespace DiviManagerPro\Woocommerce;

defined( 'ABSPATH' ) or die( 'Unexpected access' );

use DiviManager\Registry;

/**
 * Add menu for woocommerce interaction
 *
 * @see https://codex.wordpress.org/Adding_Administration_Menus
 */
class Admin
{
    /**
     * @var Registry the core class
     */
    protected $registry;

    /**
     * @var String plugin slug, used as base for options
     */
    protected $slug;

    /**
     * @var Option options manager
     */
    protected $option;

    /**
     * @var Woocommerce the woocommerce extension main class
     */
    protected $woocommerce;

    public function __construct()
    {
        $this->slug = 'divimanager-pro';
    }

    public function setOption($option)
    {   
        $this->option = $option;
    }

    public function setWoocommerce(Woocommerce $w)
    {
        $this->woocommerce = $w;
    }

    public function setRegistry(Registry $registry)
    {   
        $this->registry = $registry;
    }

    public function setSlug(String $s)
    {
        $this->slug = $s;
    }

	public function init()
    {   
        add_action( 'admin_menu', [$this, 'admin_menu'], 14 );
        add_filter( 'divimanager_mysettings', [$this, 'register_mysettings'], 4 );
        add_filter( 'divimanager_options_validate', [$this, 'plugin_options_validate'] );
    }
    
    public function register_mysettings($settings)
    {
        $sectionName = $this->slug . '_section_woocommerce';
        $optionName = $this->option->getOptionName();
        $settings[$this->slug . '-woocommerce'] = [
			$sectionName,
			'Woocommerce Settings',
			[$this, 'woocommerce_settings'],
			$optionName,
            'settings' => [
            ]
        ];
        $settings[$this->slug . '-woocommerce']['settings'][] = [   
            $this->slug . '_field_woocommerce_enabled',
            'Woocommerce Enabled',
            [$this, 'plugin_setting_woocommerce_enabled'],
            $optionName,
            $sectionName,
            [   
                'label_for' => 'divimanager_options[woocommerce_enabled]'
            ]
        ];
        if ($this->woocommerce->isWoocommerceEnabled()) {
            $settings[$this->slug . '-woocommerce']['settings'][] = [   
                $this->slug . '_field_woocommerce_field',
                'Woocommerce Product Field',
                [$this, 'plugin_setting_woocommerce_field'],
                $optionName,
                $sectionName,
                [   
                    'label_for' => 'divimanager_options[woocommerce][field]'
                ],
                'Field for the customer to enter the site domain',
            ];
            $settings[$this->slug . '-woocommerce']['settings'][] = [   
                $this->slug . '_field_woocommerce_label',
                'Woocommerce Field Label',
                [$this, 'plugin_setting_woocommerce_label'],
                $optionName,
                $sectionName,
                [   
                    'label_for' => 'divimanager_options[woocommerce][label]'
                ],
                'Label for the field, displayed in order emails and other pages',
            ];
        }

        return $settings;
    }

	public function admin_menu ()
    {
        $wcMenuPage = $this->registry->getService(Page\WCMenu::class);

        $wcMenuPageHook = add_submenu_page( 'divimanager-menu', 'Woocommerce', 'Woocommerce', 'manage_options', 'divimanager-woocommerce-main', [$wcMenuPage, 'main']);
	}

    /**
     * custom plugin settings
     */
    public function woocommerce_settings($args)
    {   
        echo '<p id="' . esc_attr( $args['id'] ) . '">All the settings which the woocommerce extension will use.</p>';
        if (! $this->woocommerce->isWCSActive()) {
            echo '<p id="' . esc_attr( $args['id'] ) . '">Woocommerce Subscriptions are currently inactive, please install and activate to use thease features.</p>';
        }
    }

    public function plugin_setting_woocommerce_enabled($args)
    {
        if ($this->woocommerce->isWCSActive()) {
            $enabled = $this->option->getOption('woocommerce_enabled');
            if (true == $enabled) {
                $checked = 'checked';
            } else {
                $checked = '';
            }
            echo '<input id="' . esc_attr( $args['label_for'] ) . '" name="' . esc_attr( $args['label_for'] ) . '" type="checkbox" size="40" value="true" '.$checked.' />';
        } else {
            echo '<input id="' . esc_attr( $args['label_for'] ) . '" name="' . esc_attr( $args['label_for'] ) . '" type="checkbox" size="40" value="true" disabled />';
        }
    }

    public function plugin_setting_woocommerce_field($args)
    {
        $field = $this->option->getOption('woocommerce')['field'];
        echo '<input id="' . esc_attr( $args['label_for'] ) . '" name="' . esc_attr( $args['label_for'] ) . '" type="text" value="' . esc_attr ( $field ) . '" />';
    }

    public function plugin_setting_woocommerce_label($args)
    {
        $label = $this->option->getOption('woocommerce')['label'];
        echo '<input id="' . esc_attr( $args['label_for'] ) . '" name="' . esc_attr( $args['label_for'] ) . '" type="text" value="' . esc_attr ( $label ) . '" />';
    }

    public function plugin_options_validate($input)
    {
        $input['woocommerce']['enabled'] = isset($input['woocommerce']['enabled']) ? true == \sanitize_text_field($input['woocommerce']['enabled']) : false;
        $input['woocommerce']['field'] = isset($input['woocommerce']['field']) ? \sanitize_text_field($input['woocommerce']['field']) : null;
        $input['woocommerce']['label'] = isset($input['woocommerce']['label']) ? \sanitize_text_field($input['woocommerce']['label']) : null;

        return $input;
    }
}
