<?php declare(strict_types=1);
namespace DiviManagerPro\Woocommerce\Command;

use DiviManagerPro\Woocommerce\Woocommerce as DMPWC;
use DiviManager\Service\Site as SiteService;

/**
 * Interact with DiviManagerPro-woocommerce functionality
 */
class Cleanup extends \WP_CLI_Command
{
    /**
     * Set the dmp woocommerce extension class
     */
    public function setDmpwc(DMPWC $dmpwc)
    {
        $this->dmpwc = $dmpwc;
    }

    public function setSiteService(SiteService $sm)
    {
        $this->siteService = $sm;
    }

    /**
     * Cleanup metadata and fix associations
     *
     * This will remove "http(s)://" from domains, and add .com if it is missing.
     *
     * ## OPTIONS
     *
     * ## EXAMPLES
     *
     *     wp manager wc cleanup
     *
     * @subcommand wc cleanup
     */
    public function __invoke($args, $assoc_args )
    {
        // get the active subscriptions with profiles
        $subscriptions = $this->dmpwc->getProfileSubscriptions();
        foreach ($subscriptions as $subscription) {
            $domain = $this->dmpwc->getDomainForItem($subscription);
            $domain = SiteModel::stripSchemeFromUrl($domain);
            $this->dmpwc->setDomainForItem($subscription, $domain);

            $parent_id = $subscription->get_related_orders('id', 'parent');
            $parentOrder = new WC_Order($parent_id);
            $this->dmpwc->setDomainForItem($parentOrder, $domain);

            $site = $this->siteService->getSiteByDomain($domain);
            if (null === $site) {
                continue; // no site found for this order
            }

            $site->setOrderId($subscription->ID);
            $this->siteService->updateSite($site);
        }

        \WP_CLI::success( 'Done' );
    }
}
