<?php declare(strict_types=1);
namespace SLManager\Woocommerce\Page;

defined( 'ABSPATH' ) or die( 'Unexpected access' );

namespace DiviManagerPro\Woocommerce\Page;

defined( 'ABSPATH' ) or die( 'Unexpected access' );

use DiviManager\Service\Site as SiteService;
use DiviManager\Model\Site as SiteModel;
use DiviManager\Helper;
use DiviManagerPro\Woocommerce\Woocommerce as DMPWC;
use DiviManagerPro\Woocommerce\Table\Order as OrderTable;

/**
 * Main menu for Woocommerce extension
 */
class WCMenu
{
    /**
     * @var DiviManager\Woocommerce\Woocommerce
     */
    protected $dmpwc;

    protected $siteService;
    protected $orderTable;

    public function __construct(DMPWC $dmpwc, SiteService $siteService, OrderTable $orderTable)
    {
        $this->dmpwc = $dmpwc;
        $this->siteService = $siteService;
        $this->orderTable = $orderTable;
    }

    /**
     * Main page
     */
    public function main ()
    {
        // is this access check necessary?
        if ( !current_user_can( 'manage_options' ) )  {
            wp_die( __( 'You do not have sufficient permissions to access this page.' ) );
        }

        try {
            $this->orderTable->prepare_items();
        } catch (\Exception $e) {
            Helper::adminMessage('We encountered an error with the sites: ' . $e->getMessage(), Helper::ERROR);
        }
?>
    <div class="wrap">
        <h1 class="wp-heading-inline"><?php echo esc_html( get_admin_page_title() ); ?></h1>
        <p>The Woocommerce extension to the manager requires some additional setup to be fully functional.  Any product or subscription needs to have a manager profile selected.  Profiles are a standard part of the manager and do not require this extension.  After creating a profile, go to the product and select the profile to be associated with that product.</p>
        <p>When an order is competed this extension will notify the manager of the new site.  This only works on products with a selected profile, not the "not a site" default.  Also, products and subscriptions need the "virtual" and "downloadable" checkboxes checked in order for Woocommerce to process the order into the completed status.  Otherwise you will need to mark the order as completed.</p>
        <p>The import feature shown below will import any matching orders creating, or updating, sites in the manager.  If the site, by matching the domain, already exists then its order and customer will be updated.  If the site does not exists it will be created.  Again this only works on products with a selected profile.</p>
        <p>NOTE:  Currently this only works for subscriptions.</p>
        <div id="post-body" class="metabox-holder columns-2">
            <div id="post-body-content">
<form class="search-form search-plugins" method="post">
<?php $this->orderTable->search_box( __( 'Search Orders' ), 'order' ); ?>
</form>
                <div class="meta-box-sortables ui-sortable">
                    <form method="post">
<?php
                    try {
                        $this->orderTable->display();
                    } catch (\Exception $e) {
                        Helper::adminMessage('We encountered an error with the sites: ' . $e->getMessage(), Helper::ERROR);
                    }
?>
                    </form>
                </div>
            </div>
        </div>
        <br class="clear">
	</div>
<?php
    }
}
